/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#ifndef _U2_FOREVER_TASK_H_
#define _U2_FOREVER_TASK_H_

#include <U2Core/Task.h>

namespace U2 {

/* need for congene not to die */
class ForeverTask : public Task {
    Q_OBJECT
public:
    ForeverTask();
    ~ForeverTask();
    
    virtual void run();
    
}; // ForeverTask

} // U2

#endif // _U2_FOREVER_TASK_H_
